summaryrefslogtreecommitdiff
path: root/bip-0075
diff options
context:
space:
mode:
Diffstat (limited to 'bip-0075')
-rw-r--r--bip-0075/paymentrequest.proto14
1 files changed, 8 insertions, 6 deletions
diff --git a/bip-0075/paymentrequest.proto b/bip-0075/paymentrequest.proto
index 8f39c6d..149dc97 100644
--- a/bip-0075/paymentrequest.proto
+++ b/bip-0075/paymentrequest.proto
@@ -17,12 +17,14 @@ message Output {
}
message PaymentDetails {
optional string network = 1 [default = "main"]; // "main" or "test"
- repeated Output outputs = 2; // Where payment should be sent
- required uint64 time = 3; // Timestamp; when payment request created
- optional uint64 expires = 4; // Timestamp; when this request should be considered invalid
- optional string memo = 5; // Human-readable description of request for the customer
- optional string payment_url = 6; // URL to send Payment and get PaymentACK
- optional bytes merchant_data = 7; // Arbitrary data to include in the Payment message
+ repeated Output outputs = 2; // Where payment should be sent
+ required uint64 time = 3; // Timestamp; when payment request created
+ optional uint64 expires = 4; // Timestamp; when this request should be considered invalid
+ optional string memo = 5; // Human-readable description of request for the customer
+ optional string payment_url = 6; // URL to send Payment and get PaymentACK
+ optional bytes merchant_data = 7; // Arbitrary data to include in the Payment message
+ optional bool subtract_fee = 1000; // Allow SubtractableFee
+ //optional bool replace_by_fee = 1001; // Force RBF true or false (version: 2)
}
message PaymentRequest {
optional uint32 payment_details_version = 1 [default = 1];